<?php

App::uses('EvCaseStudiesAppController', 'EvCaseStudies.Controller');

class CaseStudiesController extends EvCaseStudiesAppController {

	public function adminPopulateLookups() {
		$this->loadModel('EvCaseStudies.CaseStudyCategories');
		$caseStudyCategories = $this->CaseStudyCategories->find('list');

		$this->set('caseStudyCategories', $caseStudyCategories);
	}

	public function beforeFilter() {
		parent::beforeFilter();

		$this->Auth->allow(array(
			'index',
			'view'
		));
	}

	protected function _adminFormFields() {
		$result = parent::_adminFormFields();

		$result['CaseStudy.body']['type'] = 'html';

		return $result;
	}

	/**
	 * index
	 *
	 * Displays all active Case Studies with pagination
	 */
	public function index() {
		$Model = $this->{$this->modelClass};

		// see if there is a linked content page
		$pageId = Configure::read('EvCaseStudies.page_id');

		if (!empty($pageId)) {
			$this->assignPage($pageId, 'page');
		}

		$this->paginate = array(
			'conditions' => array(
				'CaseStudy.is_active' => 1
			),
			'order' => 'CaseStudy.sequence ASC',
			'contain' => array(
				'CaseStudyCategory',
				'FeaturedImage',
				'GalleryImage'
			),
			'limit' => Configure::read('EvCaseStudies.page_limit')
		);

		$this->set('data', $this->paginate());

		// call the widgets
		$this->widgetLatestCaseStudies();
		$this->widgetCategories();

		$this->view = 'EvCaseStudies.CaseStudies/index';
	}

	/**
	 * view
	 *
	 * Displays a specific case study based on it's id
	 * @param  int $id ID of the case study to display
	 */
	public function view($id) {
		$Model = $this->{$this->modelClass};

		$data = $Model->readForView($id);
		$this->Meta->set($data);

		$this->set('data', $data);

		// call the widgets
		$this->widgetLatestCaseStudies();
		$this->widgetCategories();

		$this->view = 'EvCaseStudies.CaseStudies/view';
	}

}
