<?php

App::uses('EvCaseStudiesAppModel', 'EvCaseStudies.Model');
App::uses('String', 'Utility');

class CaseStudy extends EvCaseStudiesAppModel {

	public $actsAs = array(
		'Routable.Routable' => array(
			'alias' => 'case-studies/:displayField',
			'config' => 'EvCaseStudies'
		),
		'MetaData.Meta'
	);

	public $imageSlots = array(
		'featured' => array(
			'fields' => array(
				'alt'
			),
			'slots' => 1
		),
		'gallery' => array(
			'fields' => array(
				'alt'
			),
			'slots' => -1
		),
	);

	public $documentSlots = array(
			'main' => array(
				'fields' => array(
					'caption' => array(
						'label' => 'Link Text', //This array is passed through to FormHelper::input so can be used to  add class etc.
					)
				),
				'slots' => 1
			)
		);

	public $validate = array(
		'name' => array(
			'notBlank' => array(
				'rule' => array('notBlabk')
			),
		),
		'case_study_category_id' => array(
			'notBlank' => array(
				'rule' => array('notBlank')
			)
		)
	);

	public $belongsTo = array(
		'CaseStudyCategory' => array(
			'className' => 'EvCaseStudies.CaseStudyCategory'
		)
	);

	public function readForEdit($id, $query = array()) {
		$query['contain'][] = 'CaseStudyCategory';

		return parent::readForEdit($id, $query);
	}

	public function afterFind($results, $primary = false) {
		$results = parent::afterFind($results, $primary);
		$length = Configure::read('EvCaseStudies.snippet_length');

		$snippetConf = Configure::read('EvCaseStudies.snippet');

		foreach ($results as $k => $casestudy) {

			if (isset($casestudy['CaseStudy'])) {

				$snippet = strip_tags($casestudy['CaseStudy']['body']);

				$snippet = String::truncate($snippet, $snippetConf['length'], array(
					'exact' => $snippetConf['exact'],
					'ellipsis' => $snippetConf['ellipsis']
				));

				$results[$k]['CaseStudy']['snippet'] = $snippet;
			}

			if (! isset($casestudy['CaseStudy']['case_study_category_id']) || empty($casestudy['CaseStudy']['case_study_category_id'])) {

				$results[$k]['CaseStudy']['case_study_category_id'] = 0;
			}
		}

		return $results;
	}

	/**
	 * Query array for getting case studies
	 * Default settings are for listing
	 *
	 * @return  array
	 */
	public function listingQueryArray() {
		return array(
			'conditions' => array(
				'CaseStudy.is_active' => 1
			),
			'order' => 'CaseStudy.sequence ASC',
			'contain' => 'Image',
			'limit' => Configure::read('CaseStudy.page_limit')
		);
	}

}
